@@ -14,17 +14,26 @@ def implausibility(
     obs_err: np.ndarray,
 ):
     """
-    Calculate implausability score for set of predictions
+    Calculate implausibility score for set of predictions
 
     Input:
     predict_mean (ndarray) - (n_features,n_samples) Array of predictions
     obs_mean (ndarray) - (n_features) Mean of observational data
-    predict_err - Standard Error in predictoins
+    predict_err - Standard Error in predictions
     obs_err- Standard error in mean of observations
     """
+    n_features = obs_mean.shape[0]
+    if n_features != predict_mean.shape[0]:
+        raise ValueError("Incompatible shapes between observations and predictions")
     return np.sqrt(
-        np.abs(predict_mean - obs_mean[:, None])
-        / np.sqrt(predict_err[:, None] ** 2 + obs_err**2)
+        np.sum(
+            [
+                (predict_mean[i] - obs_mean[i]) ** 2
+                / (predict_err[i] ** 2 + obs_err[i] ** 2)
+                for i in range(n_features)
+            ],
+            axis=0,
+        )
     )
 
 
@@ -39,6 +48,10 @@ class GPEmulator(BaseEstimator):
         self.__std_y = None
 
     def fit(self, X, y, y_err):
+        if X.shape[-1] != self.n_features:
+            raise ValueError(
+                "Last dimension of x do not agree with the specified n_features "
+            )
         if len(y.shape) == 1:
             y = y[:, None]
         if len(y_err.shape) == 1:
@@ -67,9 +80,9 @@ class GPEmulator(BaseEstimator):
         values = np.array([gp.predict(X, return_std=return_std) for gp in self.gps])
         if return_std:
             return np.transpose(
-                (values[:, 0, :] * self.__std_y) + self.__mean_y
-            ), np.transpose(values[:, 1, :] * self.__std_y)
-        return np.transpose(values * self.__std_y + self.__mean_y)
+                (values[:, 0, :] * self.__std_y[:, None]) + self.__mean_y[:, None]
+            ), np.transpose(values[:, 1, :] * self.__std_y[:, None])
+        return np.transpose(values * self.__std_y[:, None] + self.__mean_y[:, None])
 
     def predict_over_space(self, space: SampleSpace, return_std=False, resolution=None):
         """
